@@ -193,6 +193,25 @@ ACP_ABI = [
     "name": "JobCreated",
     "type": "event"
   },
+  {
+    "anonymous": False,
+    "inputs": [
+      {
+        "indexed": True,
+        "internalType": "uint256",
+        "name": "jobId",
+        "type": "uint256"
+      },
+      {
+        "indexed": True,
+        "internalType": "address",
+        "name": "paymentToken",
+        "type": "address"
+      }
+    ],
+    "name": "JobPaymentTokenSet",
+    "type": "event"
+  },
   {
     "anonymous": False,
     "inputs": [
@@ -342,6 +361,49 @@ ACP_ABI = [
     "name": "PayableFeeRequestExecuted",
     "type": "event"
   },
+  {
+    "anonymous": False,
+    "inputs": [
+      {
+        "indexed": True,
+        "internalType": "uint256",
+        "name": "jobId",
+        "type": "uint256"
+      },
+      {
+        "indexed": True,
+        "internalType": "uint256",
+        "name": "memoId",
+        "type": "uint256"
+      },
+      {
+        "indexed": True,
+        "internalType": "address",
+        "name": "sender",
+        "type": "address"
+      },
+      {
+        "indexed": False,
+        "internalType": "address",
+        "name": "token",
+        "type": "address"
+      },
+      {
+        "indexed": False,
+        "internalType": "uint256",
+        "name": "amount",
+        "type": "uint256"
+      },
+      {
+        "indexed": False,
+        "internalType": "uint256",
+        "name": "feeAmount",
+        "type": "uint256"
+      }
+    ],
+    "name": "PayableFundsEscrowed",
+    "type": "event"
+  },
   {
     "anonymous": False,
     "inputs": [
@@ -736,6 +798,11 @@ ACP_ABI = [
             "internalType": "address",
             "name": "evaluator",
             "type": "address"
+          },
+          {
+            "internalType": "contract IERC20",
+            "name": "jobPaymentToken",
+            "type": "address"
           }
         ],
         "internalType": "struct ACPSimple.Job",
@@ -1333,6 +1400,11 @@ ACP_ABI = [
         "internalType": "address",
         "name": "evaluator",
         "type": "address"
+      },
+      {
+        "internalType": "contract IERC20",
+        "name": "jobPaymentToken",
+        "type": "address"
       }
     ],
     "stateMutability": "view",
@@ -1564,6 +1636,29 @@ ACP_ABI = [
     "stateMutability": "nonpayable",
     "type": "function"
   },
+  {
+    "inputs": [
+      {
+        "internalType": "uint256",
+        "name": "jobId",
+        "type": "uint256"
+      },
+      {
+        "internalType": "uint256",
+        "name": "amount",
+        "type": "uint256"
+      },
+      {
+        "internalType": "contract IERC20",
+        "name": "jobPaymentToken_",
+        "type": "address"
+      }
+    ],
+    "name": "setBudgetWithPaymentToken",
+    "outputs": [],
+    "stateMutability": "nonpayable",
+    "type": "function"
+  },
   {
     "inputs": [
       {
@@ -1660,6 +1755,19 @@ ACP_ABI = [
     "outputs": [],
     "stateMutability": "nonpayable",
     "type": "function"
+  },
+  {
+    "inputs": [
+      {
+        "internalType": "uint256",
+        "name": "memoId",
+        "type": "uint256"
+      }
+    ],
+    "name": "withdrawEscrowedFunds",
+    "outputs": [],
+    "stateMutability": "nonpayable",
+    "type": "function"
   }
 ]
 
